@@ -1,9 +1,9 @@
 from abc import ABC
-from GhostScan.CalibrationSession import CalibrationSession
+from GhostScan.CalibrationSessions import CalibrationSession
 
 
 class IntrinsicCalibSession(CalibrationSession, ABC):
-    def __init__(self, camera, intrinsic_calib, path='CalibrationImages', no=20):
+    def __init__(self, camera, intrinsic_calib, path='CalibrationImages', no=5):
         # Set camera
         self.camera = camera
         self.path = path
@@ -19,7 +19,8 @@ class IntrinsicCalibSession(CalibrationSession, ABC):
             # Save images for calibration in .RAW and .PNG format
             filename = 'intr_' + str(i)
             self.camera.getImage(name='/Intrinsic/'+filename, calibration=True)
-            print("Alternate the viewing direction of the camera...")
+            print("Alternate the viewing direction of the camera..." + str(i))
+        cv2.destroyAllWindows()
 
     def calibrate(self, imgFolder='CalibrationImages/Intrinsic', imgPattern="*.PNG"):
         # Call calibration in calibration object
