@@ -1,6 +1,6 @@
 from abc import ABC
-from CalibrationSession import CalibrationSession
-from GhostScan.Calibrations import RadiometricCalibration
+from GhostScan.CalibrationSessions import CalibrationSession
+from Calibrations import RadiometricCalibration
 import cv2
 import os, sys, time, math
 import numpy as np
