@@ -1,5 +1,5 @@
 from pypylon import pylon
-from GhostScan.Camera import Camera
+from GhostScan.Cameras import Camera
 from abc import ABC
 import numpy as np
 import cv2
@@ -8,8 +8,9 @@ from skimage import io
 from io import BytesIO
 from IPython.display import clear_output, Image, display, update_display
 import PIL
-from GhostScan.Cameras.liveDisplay import ptgCamStream, imgShow, patternDisplay
-from GhostScan.Cameras.PySpinCapture import PySpinCapture as psc
+from Cameras.liveDisplay import ptgCamStream, imgShow, patternDisplay
+from Cameras.PySpinCapture import PySpinCapture as psc
+import matplotlib.pyplot as plt
 
 class Basler(Camera, ABC):
 
@@ -245,7 +246,7 @@ class Flir(Camera, ABC):
 
         self._is16bits = True
 
-        # self.NumPatterns = NUM_PATTERN
+        self.NumPatterns = NUM_PATTERN
         self.displayWidth = DISPLAY_WIDTH
         self.displayHeight = DISPLAY_HEIGHT
 
@@ -267,33 +268,17 @@ class Flir(Camera, ABC):
     def getImage(self, name='test', saveImage=True, saveNumpy=True, calibration=False, timeout=5000, calibrationName = None):
 
         try:
-
             # Take and return current camera frame
-
             success, img = self.Cam.grabFrame()
-            #print(img.shape)
-
             # Save if desired
-
             if saveImage:
-
                 if calibration:
                     #filename = 'CalibrationImages/' + name + '.raw'
-                    if calibrationName is None:
-
-                        filenamePNG = 'CalibrationImages/' + name + '.PNG'
-
-                        cv2.imwrite(filenamePNG, cv2.cvtColor(img, cv2.COLOR_BGR2RGB))
-                    
-                    else:
-                        filenamePNG = os.path.join('CalibrationImages/' + calibrationName,  name + '.PNG')
-
-                        cv2.imwrite(filenamePNG, cv2.cvtColor(img, cv2.COLOR_BGR2RGB))
+                    filenamePNG = 'CalibrationImages/' + name + '.PNG'
+                    cv2.imwrite(filenamePNG,cv2.cvtColor(img,cv2.COLOR_BGR2RGB))
                     
                 else:
-
                     filename = 'CapturedImages/' + name + '.PNG'
-
                     cv2.imwrite(filename, cv2.cvtColor(img, cv2.COLOR_BGR2RGB))
 
             if saveNumpy:
@@ -555,21 +540,13 @@ class Flir(Camera, ABC):
         while True:
 
             _,img = self.Cam.grabFrameCont()
-
             cv2.imshow('FLIR camera image', img)
-
             c = cv2.waitKey(1)
-
             if c != -1:
-
                 # When everything done, release the capture
-
                 self.Cam._camera.EndAcquisition()
-
                 cv2.destroyAllWindows()
-
                 self.quit_and_open()
-
                 break
 
             
@@ -579,39 +556,20 @@ class Flir(Camera, ABC):
         # Live view in a Jupyter Notebook
 
         try:
-
             start = self.getImage(saveImage=False, saveNumpy=False)
-
+            start = start.astype(np.uint8)
             g = BytesIO()
-
-            PIL.Image.fromarray(start).save(g, 'jpeg')
-
             obj = Image(data=g.getvalue())
-
             dis = display(obj, display_id=True)
-
             while True:
-
                 img = self.getImage(saveImage=False, saveNumpy=False)
-
-                if img is None:
-
-                    break
-
                 img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
-
+                img = img.astype(np.uint8)
                 f = BytesIO()
-
                 PIL.Image.fromarray(img).save(f, 'jpeg')
-
                 obj = Image(data=f.getvalue())
-
                 update_display(obj, display_id=dis.display_id)
-
-                clear_output(wait=True)
-
         except KeyboardInterrupt:
-
             self.quit_and_open()
 
             
