@@ -1,6 +1,6 @@
 import numpy as np
 import cv2
-from GhostScan.Camera import Camera
+from GhostScan.Cameras import Camera
 import time
 import matplotlib.pyplot as plt
 import sys
@@ -53,8 +53,8 @@ class Internal(Camera, ABC):
 
     def getResolution(self):
         # Returns a tuple resolution (width, height)
-        width = self.cap.get(cv2.CAP_PROP_FRAME_WIDTH)
-        height = self.cap.get(cv2.CAP_PROP_FRAME_HEIGHT)
+        width = int(self.cap.get(cv2.CAP_PROP_FRAME_WIDTH))
+        height = int(self.cap.get(cv2.CAP_PROP_FRAME_HEIGHT))
         return width, height
 
     def setResolution(self, resolution):
@@ -80,6 +80,7 @@ class Internal(Camera, ABC):
                 np.save('CapturedNumpyData/' + name, cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
         return frame
 
+
     def setAutoExposure(self):
         # Turn on auto exposure
         self.cap.set(cv2.CAP_PROP_AUTO_EXPOSURE, 0.75)
@@ -108,20 +109,15 @@ class Internal(Camera, ABC):
     def viewCameraStreamJupyter(self):
         # Live view in a Jupyter Notebook
         try:
-            start = self.getImage(saveImage=False, saveNumpy=False)
-            g = BytesIO()
-            PIL.Image.fromarray(start).save(g, 'jpeg')
-            obj = Image(data=g.getvalue())
-            dis = display(obj, display_id=True)
             while True:
-                img = self.getImage(saveImage=False, saveNumpy=False)
-                img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
-                f = BytesIO()
-                PIL.Image.fromarray(img).save(f, 'jpeg')
-                obj = Image(data=f.getvalue())
-                update_display(obj, display_id=dis.display_id)
+                start = self.getImage(saveImage=False, saveNumpy=False)
+                start = cv2.cvtColor(start,cv2.COLOR_BGR2RGB)
+                g = BytesIO()
+                PIL.Image.fromarray(start).save(g, 'jpeg')
+                obj = Image(data=g.getvalue())
+                dis = display(obj, display_id=True)
                 clear_output(wait=True)
-        except KeyboardInterrupt:
+        except KeyboardInterrupt: 
             self.quit_and_open()
 
     def viewCameraStreamJupyterBokeh(self):
@@ -257,20 +253,15 @@ class External(Camera):
     def viewCameraStreamJupyter(self):
         # Live view in a Jupyter Notebook
         try:
-            start = self.getImage(saveImage=False, saveNumpy=False)
-            g = BytesIO()
-            PIL.Image.fromarray(start).save(g, 'jpeg')
-            obj = Image(data=g.getvalue())
-            dis = display(obj, display_id=True)
             while True:
-                img = self.getImage(saveImage=False, saveNumpy=False)
-                img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
-                f = BytesIO()
-                PIL.Image.fromarray(img).save(f, 'jpeg')
-                obj = Image(data=f.getvalue())
-                update_display(obj, display_id=dis.display_id)
+                start = self.getImage(saveImage=False, saveNumpy=False)
+                start = cv2.cvtColor(start,cv2.COLOR_BGR2RGB)
+                g = BytesIO()
+                PIL.Image.fromarray(start).save(g, 'jpeg')
+                obj = Image(data=g.getvalue())
+                dis = display(obj, display_id=True)
                 clear_output(wait=True)
-        except KeyboardInterrupt:
+        except KeyboardInterrupt: 
             self.quit_and_open()
 
     def quit_and_close(self):
